# Scitacean

Scitacean is a high level Python package for downloading and uploading datasets from and to [SciCat](https://scicatproject.github.io/).

See the [documentation](https://scicatproject.github.io/scitacean/) for installation and usage instructions.

If you need help, have a look at our GitHub [discussions](https://github.com/SciCatProject/scitacean/discussions).
For questions, please start a [Q&A discussion](https://github.com/SciCatProject/scitacean/discussions/categories/q-a) if your questions hasn't already been asked.
